<?php
/*
Plugin Name: Folder Slideshow
Version: 0.97
Plugin URI: http://www.jalby.org/wordpress/
Author: Vincent Jalby
Author URI: http://www.jalby.org
Description: This plugin creates picture slideshow from a folder. The slideshow is generated in a post or page with a shortcode. Usage: [folderslideshow folder="local_path_to_folder"].
Tags: slideshow, folder, slidesjs
Requires: 3.5
License: GPLv2
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/

/*  Copyright 2013  Vincent Jalby  (wordpress /at/ jalby /dot/ org)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


new folderslideshow();

class folderslideshow{

	function folderslideshow() {		
		add_action( 'wp_enqueue_scripts', array( $this, 'fs_styles' ) );
		add_shortcode( 'folderslideshow', array( $this, 'fs_slideshow' ) );
		add_action('plugins_loaded', array( $this, 'fs_init' ) );
	}

	function fs_init() {
		if ( !is_admin() ) add_filter( 'widget_text', array( $this, 'fs_widget_shortcode' ), 11 );
	}
	
	function fs_widget_shortcode( $content ) {
		if ( false === stripos( $content, '[folderslideshow' ) ) {
			return $content;
		} else {
			return do_shortcode( $content );
		}
	}
	
	function fs_styles() {
		wp_enqueue_style( 'fs-style', plugins_url( 'fs-style.css', __FILE__ ) );
	}

	function fs_scripts( $param ) {
		wp_enqueue_script( 'fs_slides-script', plugins_url( 'jquery.slides.min.js', __FILE__ ), array( 'jquery' ) );
		wp_enqueue_script( 'fs_slideshow-script', plugins_url( 'fs-slideshow.js', __FILE__ ), array( 'jquery' ) );
		wp_localize_script( 'fs_slideshow-script', 'FSparam', $param );
	}

	function file_array( $directory ) { // List all JPG & PNG files in $directory
		$files = array();
		if( $handle = opendir( $directory ) ) {
			while ( false !== ( $file = readdir( $handle ) ) ) {
				$ext = strtolower( pathinfo( $file, PATHINFO_EXTENSION ) );
				if ( 'jpg' == $ext || 'png' == $ext ) {
					$files[] = $file;
				}
			}
			closedir( $handle );
		}
		sort( $files );
		return $files;
	}
				
	function fs_slideshow( $atts ) { // Generate gallery
		extract( shortcode_atts( array(
			'folder'  => 'wp-content/uploads/',
			'width'   => 0,
			'padding' => 0,
			'border' => 0,
			'interval' => 4000,
			'pagination' => true,
			'effect' => 'slide',
		), $atts ) );

		$folder = rtrim( $folder, '/' ); // Remove trailing / from path

		if ( !is_dir( $folder ) ) {
			return '<p style="color:red;"><strong>Folder Slideshow Error: </strong>Unable to find the directory ' . $folder . '</p>' ;
		}
	
		$pictures = $this->file_array( $folder );
		$NoP = count( $pictures );

		if ( 0 == $NoP ) {
			return '<p style="color:red;"><strong>Folder Slideshow Error: </strong>No picture available inside '. $folder . '</p>';
		}
		// Image size required by SlidesJS
		$size = getimagesize( $folder . '/' . $pictures[0] );
		$pwidth = $size[0];
		$pheight = $size[1];
		// SlidesJS paramaters
		$param = array( 'width'=>$pwidth, 'height'=>$pheight, 'interval'=>$interval, 'pagination'=>$pagination, 'paginationWidth'=>$NoP*16, 'effect'=>$effect );
		$this->fs_scripts($param);

		$slideshow_code = '<div class="fs_slideshow" style="';
		if ( 0 != $width )  $slideshow_code .= 'width:' . $width . 'px;';
		$slideshow_code .= 'border:' . $border . 'px solid #ddd;padding:' . $padding . 'px">';	
		
		$slideshow_code .= '<div id="slides">';
		
		for ( $idx = 0 ; $idx < $NoP ; $idx++ ) {	
			$slideshow_code .= '<img src="' . home_url( '/' ) . $folder . '/' . $pictures[ $idx ] . '"';
			//$slideshow_code .= " width=\"$width\" height=\"$height\"";
			$slideshow_code .= ' alt="' . $pictures[ $idx ] . '" />' . "\n";
		}
		
		$slideshow_code .= '</div></div>' . "\n";
		
		return $slideshow_code;
	}
		
} //End Of Class

?>